# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.object import manager_pb2 as prodvana_dot_object_dot_manager__pb2


class ObjectManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.QueryObjects = channel.unary_unary(
                '/prodvana.object.ObjectManager/QueryObjects',
                request_serializer=prodvana_dot_object_dot_manager__pb2.QueryObjectReq.SerializeToString,
                response_deserializer=prodvana_dot_object_dot_manager__pb2.QueryObjectResp.FromString,
                )
        self.GetLabels = channel.unary_unary(
                '/prodvana.object.ObjectManager/GetLabels',
                request_serializer=prodvana_dot_object_dot_manager__pb2.GetLabelsReq.SerializeToString,
                response_deserializer=prodvana_dot_object_dot_manager__pb2.GetLabelsResp.FromString,
                )


class ObjectManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def QueryObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLabels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ObjectManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'QueryObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryObjects,
                    request_deserializer=prodvana_dot_object_dot_manager__pb2.QueryObjectReq.FromString,
                    response_serializer=prodvana_dot_object_dot_manager__pb2.QueryObjectResp.SerializeToString,
            ),
            'GetLabels': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLabels,
                    request_deserializer=prodvana_dot_object_dot_manager__pb2.GetLabelsReq.FromString,
                    response_serializer=prodvana_dot_object_dot_manager__pb2.GetLabelsResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.object.ObjectManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ObjectManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def QueryObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.object.ObjectManager/QueryObjects',
            prodvana_dot_object_dot_manager__pb2.QueryObjectReq.SerializeToString,
            prodvana_dot_object_dot_manager__pb2.QueryObjectResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLabels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.object.ObjectManager/GetLabels',
            prodvana_dot_object_dot_manager__pb2.GetLabelsReq.SerializeToString,
            prodvana_dot_object_dot_manager__pb2.GetLabelsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
